@@ -2,7 +2,7 @@
 /*
  * gsf-input-textline.c: textline based input
  *
- * Copyright (C) 2002-2004 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2006 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2.1 of the GNU Lesser General Public
@@ -52,7 +52,7 @@ typedef struct {
  *
  * <note>This adds a reference to @source.</note>
  *
- * Returns a new file or NULL.
+ * Returns: a new file or %NULL.
  **/
 GsfInput *
 gsf_input_textline_new (GsfInput *source)
@@ -62,11 +62,14 @@ gsf_input_textline_new (GsfInput *source)
 	g_return_val_if_fail (source != NULL, NULL);
 
 	input = g_object_new (GSF_INPUT_TEXTLINE_TYPE, NULL);
+	if (G_UNLIKELY (NULL == input)) return NULL;
+
 	g_object_ref (G_OBJECT (source));
 	input->source = source;
 	input->buf  = NULL;
 	input->buf_size = 0;
-	gsf_input_set_size (GSF_INPUT (source), gsf_input_size (source));
+	gsf_input_set_size (GSF_INPUT (input), gsf_input_size (source));
+	gsf_input_set_name (GSF_INPUT (input), gsf_input_name (source));
 
 	return GSF_INPUT (input);
 }
@@ -92,6 +95,7 @@ gsf_input_textline_dup (GsfInput *src_input, G_GNUC_UNUSED GError **err)
 {
 	GsfInputTextline const *src = (GsfInputTextline *)src_input;
 	GsfInputTextline *dst = g_object_new (GSF_INPUT_TEXTLINE_TYPE, NULL);
+	if (G_UNLIKELY (NULL == dst)) return NULL;
 
 	dst->source = src->source;
 	g_object_ref (G_OBJECT (dst->source));
@@ -143,7 +147,8 @@ gsf_input_textline_class_init (GObjectClass *gobject_class)
 }
 
 GSF_CLASS (GsfInputTextline, gsf_input_textline,
-	   gsf_input_textline_class_init, gsf_input_textline_init, GSF_INPUT_TYPE)
+	   gsf_input_textline_class_init, gsf_input_textline_init,
+	   GSF_INPUT_TYPE)
 
 /**
  * gsf_input_textline_ascii_gets :
@@ -153,7 +158,7 @@ GSF_CLASS (GsfInputTextline, gsf_input_textline,
  * Trailing newlines and carriage returns are stripped, and the resultant buffer
  * can be edited.
  *
- * Returns : the string read, or NULL on eof.
+ * Returns: the string read, or %NULL on eof.
  **/
 unsigned char *
 gsf_input_textline_ascii_gets (GsfInputTextline *textline)
@@ -240,7 +245,7 @@ gsf_input_textline_ascii_gets (GsfInputTextline *textline)
  * Trailing newlines and carriage returns are stripped, and the resultant buffer
  * can be edited.
  *
- * Returns: the string read, or NULL on eof.
+ * Returns: the string read, or %NULL on eof.
  **/
 guint8 *
 gsf_input_textline_utf8_gets (GsfInputTextline *textline)
